Stan Math Library: stan/math/prim/scal/fun/bessel_second_kind.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
bessel_second_kind.hpp File Reference
`#include <boost/math/special_functions/bessel.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T2 >
T2 | stan::math::bessel_second_kind (const int v, const T2 z)
| More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.